package com.ruoyi.fire.mapper;

import java.util.List;
import com.ruoyi.fire.domain.FireFacilityRepair;

/**
 * 消防设施维修记录Mapper接口
 * 
 * @author Junhua
 * @date 2025-07-16
 */
public interface FireFacilityRepairMapper 
{
    /**
     * 查询消防设施维修记录
     * 
     * @param id 消防设施维修记录主键
     * @return 消防设施维修记录
     */
    public FireFacilityRepair selectFireFacilityRepairById(Long id);

    /**
     * 查询消防设施维修记录列表
     * 
     * @param fireFacilityRepair 消防设施维修记录
     * @return 消防设施维修记录集合
     */
    public List<FireFacilityRepair> selectFireFacilityRepairList(FireFacilityRepair fireFacilityRepair);

    /**
     * 新增消防设施维修记录
     * 
     * @param fireFacilityRepair 消防设施维修记录
     * @return 结果
     */
    public int insertFireFacilityRepair(FireFacilityRepair fireFacilityRepair);

    /**
     * 修改消防设施维修记录
     * 
     * @param fireFacilityRepair 消防设施维修记录
     * @return 结果
     */
    public int updateFireFacilityRepair(FireFacilityRepair fireFacilityRepair);

    /**
     * 删除消防设施维修记录
     * 
     * @param id 消防设施维修记录主键
     * @return 结果
     */
    public int deleteFireFacilityRepairById(Long id);

    /**
     * 批量删除消防设施维修记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFireFacilityRepairByIds(Long[] ids);
}
