package com.ruoyi.fire.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.fire.domain.FireFacilityRepair;
import com.ruoyi.fire.service.IFireFacilityRepairService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 消防设施维修记录Controller
 * 
 * @author Junhua
 * @date 2025-07-16
 */
@RestController
@RequestMapping("/fire_facility_repair/repair")
public class FireFacilityRepairController extends BaseController
{
    @Autowired
    private IFireFacilityRepairService fireFacilityRepairService;

    /**
     * 查询消防设施维修记录列表
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_repair:repair:list')")
    @GetMapping("/list")
    public TableDataInfo list(FireFacilityRepair fireFacilityRepair)
    {
        startPage();
        List<FireFacilityRepair> list = fireFacilityRepairService.selectFireFacilityRepairList(fireFacilityRepair);
        return getDataTable(list);
    }

    /**
     * 导出消防设施维修记录列表
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_repair:repair:export')")
    @Log(title = "消防设施维修记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FireFacilityRepair fireFacilityRepair)
    {
        List<FireFacilityRepair> list = fireFacilityRepairService.selectFireFacilityRepairList(fireFacilityRepair);
        ExcelUtil<FireFacilityRepair> util = new ExcelUtil<FireFacilityRepair>(FireFacilityRepair.class);
        util.exportExcel(response, list, "消防设施维修记录数据");
    }

    /**
     * 获取消防设施维修记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_repair:repair:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fireFacilityRepairService.selectFireFacilityRepairById(id));
    }

    /**
     * 新增消防设施维修记录
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_repair:repair:add')")
    @Log(title = "消防设施维修记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FireFacilityRepair fireFacilityRepair)
    {
        return toAjax(fireFacilityRepairService.insertFireFacilityRepair(fireFacilityRepair));
    }

    /**
     * 修改消防设施维修记录
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_repair:repair:edit')")
    @Log(title = "消防设施维修记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FireFacilityRepair fireFacilityRepair)
    {
        return toAjax(fireFacilityRepairService.updateFireFacilityRepair(fireFacilityRepair));
    }

    /**
     * 删除消防设施维修记录
     */
    @PreAuthorize("@ss.hasPermi('fire_facility_repair:repair:remove')")
    @Log(title = "消防设施维修记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fireFacilityRepairService.deleteFireFacilityRepairByIds(ids));
    }
}
